import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/products/data/services/remote_products_service.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/products/presentation/bloc/products_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/tags/presentation/widgets/product_type_card.dart';
import 'package:syncrow_web/services/api/http_service.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/extension/build_context_x.dart';

class AddDeviceTypeWidget extends StatelessWidget {
  const AddDeviceTypeWidget({super.key});

  @override
  Widget build(BuildContext context) {
    final size = MediaQuery.of(context).size;
    final crossAxisCount = switch (context.screenWidth) {
      > 1200 => 8,
      > 800 => 5,
      _ => 3,
    };

    return BlocProvider(
      create: (_) => ProductsBloc(RemoteProductsService(HTTPService()))
        ..add(const LoadProducts()),
      child: Builder(
        builder: (context) => AlertDialog(
          title: const Text('Add Devices'),
          backgroundColor: ColorsManager.whiteColors,
          content: BlocBuilder<ProductsBloc, ProductsState>(
            builder: (context, state) {
              return switch (state) {
                ProductsInitial() => const Center(
                    child: CircularProgressIndicator(),
                  ),
                ProductsLoading() => const Center(
                    child: CircularProgressIndicator(),
                  ),
                ProductsLoaded(:final products) => SingleChildScrollView(
                    child: Container(
                      width: size.width * 0.9,
                      height: size.height * 0.65,
                      decoration: BoxDecoration(
                        color: ColorsManager.textFieldGreyColor,
                        borderRadius: BorderRadius.circular(8),
                      ),
                      child: Column(
                        children: [
                          const SizedBox(height: 16),
                          Expanded(
                            child: GridView.builder(
                              padding: const EdgeInsets.symmetric(
                                horizontal: 20,
                              ),
                              shrinkWrap: true,
                              gridDelegate:
                                  SliverGridDelegateWithFixedCrossAxisCount(
                                crossAxisCount: crossAxisCount,
                                mainAxisSpacing: 6,
                                crossAxisSpacing: 4,
                                childAspectRatio: 0.8,
                              ),
                              itemCount: products.length,
                              itemBuilder: (context, index) => ProductTypeCard(
                                product: products[index],
                              ),
                            ),
                          ),
                        ],
                      ),
                    ),
                  ),
                ProductsFailure(:final errorMessage) => Center(
                    child: Text(
                      errorMessage,
                      style: context.textTheme.bodyMedium?.copyWith(
                        color: context.theme.colorScheme.error,
                      ),
                    ),
                  ),
              };
            },
          ),
        ),
      ),
    );
  }
}
